DropdownItem<T> class

Constructors

Properties

child ↔ Widget?
getter/setter pair
disabled ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDivider ↔ bool
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited