Crypt class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decryptBytes(Uint8List byteData, String textKey) → List<int>
decryptTextToMap(String? textData, String textKey) → Map?
encryptBytes(Uint8List byteData, String textKey) → Uint8List
encryptMap(Map? data, String textKey) → String?
textKey minimum 4 hane olmali