CardDesign class

Constructors

CardDesign({Color text = Colors.white, Color variantText = Colors.white, Color background = Colors.black, Color button = _placeHolderColor, Color buttonText = Colors.white})
const

Properties

background → Color
final
button → Color
final
buttonText → Color
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → Color
final
variantText → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited