SelectableListItemDesign class

Constructors

SelectableListItemDesign({Color selected = _placeHolderColor, Color unselected = _placeHolderColor, Color selectedText = Colors.white, Color unselectedText = _placeHolderColor})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → Color
final
selectedText → Color
final
unselected → Color
final
unselectedText → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited