SheetDesign class

Constructors

SheetDesign({Color headerText = _placeHolderColor, Color contentText = _placeHolderColor, Color itemText = _placeHolderColor, Color background = _placeHolderColor, Color card = _placeHolderColor})
const

Properties

background → Color
final
card → Color
final
contentText → Color
final
hashCode → int
The hash code for this object.
no setterinherited
headerText → Color
final
itemText → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited