TextFieldDesign class

Constructors

TextFieldDesign({Color text = Colors.white, Color border = _placeHolderColor, Color hint = _placeHolderColor, Color fill = Colors.black})
const

Properties

border → Color
final
fill → Color
final
hashCode → int
The hash code for this object.
no setterinherited
hint → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited