SecurePreferences class

Constructors

SecurePreferences()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addItemToMap(String mapKey, String itemKey, dynamic value) → Future<void>
addLimitedStringList(String key, String text, {int maxNumber = 5}) → Future<void>
clear() → Future<void>
deleteItemMap(String mapKey, String itemKey) → Future<void>
getBool(String key, [bool? defaultValue]) → bool?
getDouble(String key, [double? defaultValue]) → double?
getInt(String key, [int? defaultValue]) → int?
getLimitedStringList(String key, [List<String>? defaultValue]) → List<String>?
getMap(String key, [Map<String, dynamic>? defaultValue]) → Map<String, dynamic>
getString(String key, [String? defaultValue]) → String?
getStringList(String key, [List<String>? defaultValue]) → List<String>?
init({int boxNo = 1}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → Future<void>
removeThisStringInStringList(String key, String text) → Future<void>
setBool(String key, bool value) → Future<void>
setDouble(String key, double value) → Future<void>
setInt(String key, int value) → Future<void>
setMap(String key, Map value) → Future<void>
setString(String key, String value) → Future<void>
setStringList(String key, List<String> value) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited