ValidatorRules class

Constructors

ValidatorRules({bool req = false, bool noGap = false, bool phoneNumber = false, bool mailAddress = false, bool firebaseSafe = false, bool mustNumber = false, bool mustInt = false, int? maxLength, int? minLength, num? minValue, num? maxValue, bool none = false})
const
ValidatorRules.none()
const

Properties

firebaseSafe → bool
final
hashCode → int
The hash code for this object.
no setterinherited
mailAddress → bool
final
maxLength → int?
final
maxValue → num?
final
minLength → int?
final
minValue → num?
final
mustInt → bool
final
mustNumber → bool
final
noGap → bool
final
none → bool
final
phoneNumber → bool
final
req → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(dynamic value) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited