SearchTextField class

Inheritance
Available extensions

Constructors

SearchTextField({Key? key, TextEditingController? controller, ValueChanged<String>? onChanged, ValueChanged<String>? onSubmitted, TextStyle? style, String? placeholder, TextStyle? placeholderStyle, BoxDecoration? decoration, Color? backgroundColor, BorderRadius? borderRadius, EdgeInsetsGeometry padding = const EdgeInsetsDirectional.fromSTEB(3.8, 8, 5, 8), Color itemColor = CupertinoColors.secondaryLabel, double itemSize = 20.0, EdgeInsetsGeometry prefixInsets = const EdgeInsetsDirectional.fromSTEB(6, 0, 0, 4), Widget prefixIcon = const Icon(CupertinoIcons.search), EdgeInsetsGeometry suffixInsets = const EdgeInsetsDirectional.fromSTEB(0, 0, 5, 2), Icon suffixIcon = const Icon(CupertinoIcons.xmark_circle_fill), OverlayVisibilityMode suffixMode = OverlayVisibilityMode.editing, VoidCallback? onSuffixTap, String? restorationId, FocusNode? focusNode, bool autofocus = false, VoidCallback? onTap, bool autocorrect = true, bool? enabled, bool enableInteractiveSelection = true})
const

Properties

amberContainer → Widget

Available on Widget, provided by the MyWidget extension

no setter
autocorrect → bool
final
autofocus → bool
final
backgroundColor → Color?
final
borderRadius → BorderRadius?
final
center → Widget

Available on Widget, provided by the MyWidget extension

no setter
controller → TextEditingController?
final
decoration → BoxDecoration?
final
enabled → bool?
final
enableInteractiveSelection → bool
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
inScaffold → Widget

Available on Widget, provided by the MyWidget extension

no setter
itemColor → Color
final
itemSize → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marginZero → Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
onChanged → ValueChanged<String>?
final
onSubmitted → ValueChanged<String>?
final
onSuffixTap → VoidCallback?
final
onTap → VoidCallback?
final
p1 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
p12 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
p16 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
p2 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
p32 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
p4 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
p8 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
padding → EdgeInsetsGeometry
final
paddingZero → Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
pb1 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pb12 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pb16 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pb2 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pb32 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pb4 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pb8 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pl1 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pl12 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pl16 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pl2 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pl32 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pl4 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pl8 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
placeholder → String?
final
placeholderStyle → TextStyle?
final
pr1 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pr12 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pr16 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pr2 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pr32 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pr4 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pr8 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
prefixIcon → Widget
final
prefixInsets → EdgeInsetsGeometry
final
pt1 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pt12 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pt16 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pt2 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pt32 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pt4 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
pt8 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
px1 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
px12 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
px16 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
px2 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
px32 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
px4 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
px8 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
py1 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
py12 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
py16 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
py2 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
py32 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
py4 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
py8 → Widget

Available on Widget, provided by the MyPaddingWidget extension

no setter
redContainer → Widget

Available on Widget, provided by the MyWidget extension

no setter
restorationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliverBox → Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
style → TextStyle?
final
suffixIcon → Icon
final
suffixInsets → EdgeInsetsGeometry
final
suffixMode → OverlayVisibilityMode
final

Methods

circleBackground({Color? background, EdgeInsets? padding}) → Widget

Available on Widget, provided by the MyWidget extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
height(double height) → Widget

Available on Widget, provided by the MyWidget extension

marginAll(double margin) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

rounded({Color? background, EdgeInsets? padding, double borderRadius = 8}) → Widget

Available on Widget, provided by the MyWidget extension

stadium({Color? background, EdgeInsets? padding}) → Widget

Available on Widget, provided by the MyWidget extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
width(double width) → Widget

Available on Widget, provided by the MyWidget extension

withKeyboardCloseGesture(BuildContext context) → Widget

Available on Widget, provided by the MyWidget extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited